@@ -136,22 +136,22 @@ def merge_tables(TT, columns=None):
     
 
 def add_nonstructural_headers(fromhdr, tohdr):
-    for card in fromhdr.ascardlist():
-        if ((card.key in ['SIMPLE','XTENSION', 'BITPIX', 'END', 'PCOUNT', 'GCOUNT',
+    for card in fromhdr.cards:
+        if ((card.keyword in ['SIMPLE','XTENSION', 'BITPIX', 'END', 'PCOUNT', 'GCOUNT',
                           'TFIELDS',]) or
-            card.key.startswith('NAXIS') or
-            card.key.startswith('TTYPE') or
-            card.key.startswith('TFORM')):
+            card.keyword.startswith('NAXIS') or
+            card.keyword.startswith('TTYPE') or
+            card.keyword.startswith('TFORM')):
             #card.key.startswith('TUNIT') or
             #card.key.startswith('TDISP')):
             #print('skipping card', card.key)
             continue
-        cl = tohdr.ascardlist()
+        cl = tohdr
         if 'END' in cl.keys():
             i = cl.index_of('END')
         else:
             i = len(cl)
-        cl.insert(i, pyfits.Card(card.key, card.value, card.comment))
+        cl.insert(i, pyfits.Card(card.keyword, card.value, card.comment))
 
 def cut_array(val, I, name=None, to=None):
     if type(I) is slice:
@@ -245,7 +245,8 @@ class tabledata(object):
             X = self.td[self.i]
             self.i += 1
             return X
-
+        # py3
+        __next__ = next
 
     def __init__(self, header=None):
         self._length = 0
@@ -297,7 +298,14 @@ class tabledata(object):
     def set(self, name, val):
         self.__setattr__(name, val)
     def getcolumn(self, name):
-        return self.__dict__[name]
+        try:
+            return self.__dict__[name]
+        except KeyError:
+            # try case-insensitive
+            for k,v in self.__dict__.items():
+                if k.lower() == name.lower():
+                    return v
+            raise
         #except:
         #   return self.__dict__[name.lower()]
     def get(self, name):
@@ -477,7 +485,16 @@ class tabledata(object):
 
             arrays = [np.array(a) if isinstance(a,list) else a
                       for a in arrays]
-
+            # py3
+            if b' ' != ' ':
+                aa = []
+                for a in arrays:
+                    if 'U' in str(a.dtype):
+                        aa.append(a.astype(np.bytes_))
+                    else:
+                        aa.append(a)
+                arrays = aa
+            
             if header == 'default':
                 header = None
             try:
@@ -505,7 +522,7 @@ class tabledata(object):
             return
 
         fc = self.to_fits_columns(columns)
-        T = pyfits.new_table(fc)
+        T = pyfits.BinTableHDU.from_columns(fc)
         if header == 'default':
             header = self._header
         if header is not None:
@@ -757,6 +774,17 @@ def fits_table(dataorfn=None, rows=None, hdunum=1, hdu=None, ext=None,
                 c = c.lower()
             T.set(c, col)
 
+    # py3: convert FITS strings from Python bytes to strings.
+    if b' ' != ' ':
+        # py3
+        for c in columns:
+            X = T.get(c)
+            t = str(X.dtype)
+            if 'S' in t:
+                X = X.astype(np.str)
+                T.set(c, X)
+                print('Converted', c, 'from', t, 'to', X.dtype)
+
     return T
 
 table_fields = fits_table
